/*
 * Copyright 2014 Peter Olsson
 * 
 * This file is part of Brum Brum Rally.
 * 
 * Brum Brum Rally is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Brum Brum Rally is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "TimeTrialMenu.h"
#include "StateManager.h"
#include "MainMenu.h"
#include "CarSelectionState.h"
#include "ErrorState.h"
#include "Settings.h"

TimeTrialMenu::TimeTrialMenu()
:	ok(false),
	cancel(false)
{
	menu.setTitle("time trial");
	
	menu.addItem("Driver name", &Settings::timetrial.name);
	menu.addItem("Remember name", &Settings::timetrial.remember, 0, 1, "no", "yes");
	menu.addItem("Ghost of this driver", &Settings::timetrial.showDriverGhost, 0, 1, "no", "yes");
	menu.addItem("Ghost of best driver", &Settings::timetrial.showBestGhost, 0, 1, "no", "yes");
	menu.addItem("Ok", &ok);
	menu.addItem("Cancel", &cancel);
	
	menu.addRenderObjects(this);
}

void TimeTrialMenu::onEvent(const SDL_Event& event)
{
	StateManager& sm = StateManager::getInstance();
	
	MenuEvent me = sm.getMenuEvent(event);
	if (menu.onEvent(me))
	{
		if (ok)
		{
			if (Settings::timetrial.name.empty())
			{
				sm.enter(new ErrorState("missing driver name", "You must enter a driver name", new TimeTrialMenu()), +1);
			}
			else
			{
				sm.enter(new CarSelectionState(CAR_SELECTION_TIME_TRIAL), +1);
			}
			return;
		}
	}
	else if (me.type == MENU_ESC)
	{
		cancel = true;
	}
	
	if (cancel)
	{
		sm.enter(new MainMenu(), -1);
	}
}

void TimeTrialMenu::onValueUpdate(std::string* strValue)
{
	if (strValue == &Settings::timetrial.name)
	{
		Settings::timetrial.remember = false;
		menu.notifyValueUpdate(&Settings::timetrial.remember);
	}
}
